==> qt-creator-2.6.2-src.zip: qt-creator-2.6.2-src/src/plugins/bazaar/bazaareditor.h <==
/**************************************************************************
**
** Copyright (c) 2013 Hugues Delorme
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef BAZAAREDITOR_H
#define BAZAAREDITOR_H

#include <vcsbase/vcsbaseeditor.h>

#include <QRegExp>

namespace Bazaar {
namespace Internal {

class BazaarEditor : public VcsBase::VcsBaseEditorWidget
{
    Q_OBJECT

public:
    explicit BazaarEditor(const VcsBase::VcsBaseEditorParameters *type, QWidget *parent);

private:
    virtual QSet<QString> annotationChanges() const;
    virtual QString changeUnderCursor(const QTextCursor &cursor) const;
    virtual VcsBase::DiffHighlighter *createDiffHighlighter() const;
    virtual VcsBase::BaseAnnotationHighlighter *createAnnotationHighlighter(const QSet<QString> &changes, const QColor &bg) const;
    virtual QString fileNameFromDiffSpecification(const QTextBlock &diffFileSpec) const;

    mutable QRegExp m_changesetId;
    mutable QRegExp m_exactChangesetId;
    mutable QRegExp m_diffFileId;
};

} // namespace Internal
} // namespace Bazaar

#endif // BAZAAREDITOR_H

==> qt-creator-2.8.0-src.zip: qt-creator-2.8.0-src/src/plugins/bazaar/bazaareditor.h <==
/**************************************************************************
**
** Copyright (c) 2013 Hugues Delorme
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef BAZAAREDITOR_H
#define BAZAAREDITOR_H

#include <vcsbase/vcsbaseeditor.h>

#include <QRegExp>

namespace Bazaar {
namespace Internal {

class BazaarEditor : public VcsBase::VcsBaseEditorWidget
{
    Q_OBJECT

public:
    explicit BazaarEditor(const VcsBase::VcsBaseEditorParameters *type, QWidget *parent);

private:
    QSet<QString> annotationChanges() const;
    QString changeUnderCursor(const QTextCursor &cursor) const;
    VcsBase::BaseAnnotationHighlighter *createAnnotationHighlighter(const QSet<QString> &changes, const QColor &bg) const;

    mutable QRegExp m_changesetId;
    mutable QRegExp m_exactChangesetId;
};

} // namespace Internal
} // namespace Bazaar

#endif // BAZAAREDITOR_H
